<?php

/**
 * @file
 * Contains the administrative functions of the salsa module.
 *
 * This file is included by the salsa module, and includes the
 * settings form.
 */

/**
 * Menu callback for the Salsa module settings form.
 *
 * @ingroup forms
 */
function salsa_settings() {
  $salsa_api_url = variable_get('salsa_api_url', 'https://salsa.democracyinaction.org');

  $node_options = array(
    'https://sandbox.salsalabs.com' => t('Developer Sandbox'),
    'https://salsa.democracyinaction.org' => t('Democracy In Action'),
    'https://org2.democracyinaction.org' => t('Democracy In Action') .' 2',
    'https://salsa.wiredforchange.com' => t('Wired for Change'),
    'https://wfc2.wiredforchange.com' => t('Wired for Change') .' 2',
  );

  $form['salsa_node'] = array(
    '#type' => 'fieldset',
    '#title' => t('Salsa node'),
    '#description' => t('Select or specify the Salsa node that stores your data.'),
  );
  $form['salsa_node']['salsa_api_url'] = array(
    '#type' => 'select',
    '#title' => t('Common shared nodes'),
    '#default_value' => in_array($salsa_api_url, array_keys($node_options)) ? $salsa_api_url : 'other',
    '#options' => $node_options + array('other' => t('Other')),
    '#description' => t('Salsa node to use (Democracy In Action, Wired for change or sandbox.)'),
    '#required' => TRUE,
  );
  $form['salsa_node']['salsa_api_url_other'] = array(
    '#type' => 'textfield',
    '#default_value' => in_array($salsa_api_url, array_keys($node_options)) ? '' : $salsa_api_url,
    '#description' => t('If Other was chosen above, please specify the schema and hostname of your Salsa node, without the trailing slash (e.g. https://server.domain.tld)'),
  );
  $form['salsa_anon_form'] = array(
    '#type' => 'fieldset',
    '#title' => t('Anonymous form credentials'),
    '#description' => t('Required for the use of anonymous supporter creation'),
  );
  $form['salsa_anon_form']['salsa_organization_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Organization key'),
    '#default_value' => variable_get('salsa_organization_key', ''),
    '#maxlength' => 10,
    '#description' => t('Organization key provided by Salsa (visible in the footer of the Salsa HQ page)'),
    '#required' => TRUE,
  );

  $form['salsa_api_auth'] = array(
    '#type' => 'fieldset',
    '#title' => t('API authentication credentials'),
    '#description' => t('Required for the use of API services'),
  );
  $form['salsa_api_auth']['salsa_api_username'] = array(
    '#type' => 'textfield',
    '#title' => t('Campaign Manager username'),
    '#default_value' => variable_get('salsa_api_username', ''),
    '#maxlength' => 64,
  );
  $form['salsa_api_auth']['salsa_api_password'] = array(
    '#type' => 'textfield',
    '#title' => t('Campaign Manager password'),
    '#default_value' => variable_get('salsa_api_password', ''),
    '#maxlength' => 64,
  );

  if (module_exists('job_queue')) {
    $form['salsa_job_queue'] = array(
      '#type' => 'checkbox',
      '#title' => t('Use Job Queue to delay saves and deletes'),
      '#default_value' => variable_get('salsa_job_queue', 0),
      '#description' => t("Enabling this option will postpone any save and delete operations to be performed by the Job Queue module during each cron run. Enabling this may result in getting data from Salsa that should have been overwritten already."),
    );
  }

  $form['#validate'][] = '_salsa_settings_validate';

  return system_settings_form($form);
}

/**
 * Validate salsa_settings form.
 */
function _salsa_settings_validate($form, &$form_state) {
  $select_other = $form_state['values']['salsa_api_url'] == 'other';
  $empty_other = empty($form_state['values']['salsa_api_url_other']);
  if (!$empty_other && $select_other) {
    // Other was selected and an input provided
    $form_state['values']['salsa_api_url'] = $form_state['values']['salsa_api_url_other'];
  }
  elseif ($empty_other && $select_other) {
    // Other was selected, but no input provided
    form_set_error('salsa_api_url_other', 'Field cannot be empty when the Salsa node is set to Other');
  }
  elseif (!$empty_other && !$select_other) {
    // Input provided, but other not selected
    form_set_error('salsa_api_url', 'Select Other when entering a custom node URL');
  }
}
